# Installing the Server Extension

```python
pip install -e .
jupyter labextension develop . --overwrite
jlpm build
```

# Devloping the JupyterLab Extension

```python
pip install -e .
jupyter labextension develop . --overwrite
jlpm build 
jupyter lab
```


